<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="el" sourcelanguage="en">
<context>
    <name>Alert</name>
    <message>
        <source>Close (%1)</source>
        <translation>Κλείσιμο (%1)</translation>
    </message>
    <message>
        <source>Collapse</source>
        <translation>Σύμπτυξη</translation>
    </message>
    <message>
        <source>Expand</source>
        <translation>Ανάπτυξη</translation>
    </message>
</context>
<context>
    <name>AlertLayer</name>
    <message>
        <source>Dismiss Alert</source>
        <translation>Απόκρυψη Ειδοποίησης</translation>
    </message>
    <message>
        <source>Ctrl+D</source>
        <translation>Ctrl+D</translation>
    </message>
</context>
<context>
    <name>DailyProgress</name>
    <message numerus="yes">
        <source>%1% of %Ln minute(s)</source>
        <translation>
            <numerusform>%1% απο %Ln λεπτο</numerusform>
            <numerusform>%1% απο %Ln λεπτά</numerusform>
        </translation>
    </message>
    <message numerus="yes">
        <source>%1% of %Ln word(s)</source>
        <translation>
            <numerusform>%1% απο %Ln λέξη</numerusform>
            <numerusform>%1% απο %Ln λέξεις</numerusform>
        </translation>
    </message>
    <message numerus="yes">
        <source>%Ln word(s)</source>
        <translation>
            <numerusform>%Ln λέξη</numerusform>
            <numerusform>%Ln λέξεις</numerusform>
        </translation>
    </message>
    <message numerus="yes">
        <source>%Ln minute(s)</source>
        <translation>
            <numerusform>%Ln λεπτο</numerusform>
            <numerusform>%Ln λεπτά</numerusform>
        </translation>
    </message>
    <message>
        <source>0%</source>
        <translation>0%</translation>
    </message>
</context>
<context>
    <name>DailyProgressDialog</name>
    <message>
        <source>Daily Progress</source>
        <translation>Καθημερινή πρόοδος</translation>
    </message>
    <message>
        <source>Longest streak</source>
        <translation>Μεγαλύτερο σερί</translation>
    </message>
    <message>
        <source>Current streak</source>
        <translation>Τρέχον σερί</translation>
    </message>
    <message>
        <source>N/A</source>
        <translation>N/A</translation>
    </message>
    <message numerus="yes">
        <source>%n day(s)</source>
        <translation>
            <numerusform>%n ημέρα</numerusform>
            <numerusform>%n ημέρες</numerusform>
        </translation>
    </message>
    <message>
        <source>%1 &amp;ndash; %2</source>
        <translation>%1 &amp;ndash; %2</translation>
    </message>
</context>
<context>
    <name>DailyProgressLabel</name>
    <message>
        <source>%1% of daily goal</source>
        <translation>%1% του ημερήσιου στόχου</translation>
    </message>
</context>
<context>
    <name>DictionaryDialog</name>
    <message>
        <source>Set Language</source>
        <translation>Ρύθμιση γλώσσας</translation>
    </message>
</context>
<context>
    <name>Document</name>
    <message>
        <source>(Untitled %1)</source>
        <translation>(Χωρίς τίτλο %1)</translation>
    </message>
    <message>
        <source>%1 (Read-Only)</source>
        <translation>%1 (μόνο για ανάγνωση)</translation>
    </message>
    <message>
        <source>Sorry</source>
        <translation>Λυπούμαστε</translation>
    </message>
    <message>
        <source>Unable to save &apos;%1&apos;.</source>
        <translation>Δεν ήταν δυνατό να αποθηκευτεί το «%1».</translation>
    </message>
    <message>
        <source>Save File As</source>
        <translation>Αποθήκευση Αρχείου Ως</translation>
    </message>
    <message>
        <source>Unable to overwrite &apos;%1&apos;.</source>
        <translation>Δεν ήταν δυνατό να αντικατασταθεί το «%1».</translation>
    </message>
    <message>
        <source>Rename File</source>
        <translation>Μετονομασία Αρχείου</translation>
    </message>
    <message>
        <source>Unable to rename &apos;%1&apos;.</source>
        <translation>Δεν ήταν δυνατό να μετονομαστεί το «%1».</translation>
    </message>
    <message>
        <source>Reload File?</source>
        <translation>Επαναφόρτωση αρχείου;</translation>
    </message>
    <message>
        <source>Reload the file &apos;%1&apos; from disk?</source>
        <translation>Επαναφόρτωση του αρχείου «%1» από τον δίσκο;</translation>
    </message>
    <message>
        <source>All unsaved changes will be lost.</source>
        <translation>Όλες οι μη αποθηκευμένες αλλαγές θα χαθούν.</translation>
    </message>
    <message>
        <source>Reload</source>
        <translation>Επαναφόρτωση</translation>
    </message>
    <message>
        <source>Untitled %1</source>
        <translation>Χωρίς τίτλο %1</translation>
    </message>
    <message>
        <source>Question</source>
        <translation>Ερώτηση</translation>
    </message>
    <message>
        <source>Saving as plain text will discard all formatting. Discard formatting?</source>
        <translation>Η αποθήκευση σε τύπο απλού κειμένου θα απορρίψει όλη τη μορφοποίηση. Απόρριψη όλης της μορφοποίησης;</translation>
    </message>
</context>
<context>
    <name>DocumentWatcher</name>
    <message>
        <source>File Changed</source>
        <translation>Το Αρχείο Έχει Αλλάξει</translation>
    </message>
    <message>
        <source>The file &apos;%1&apos; was changed by another program.</source>
        <translation>Το αρχείο %1 έχει αλλαχθεί από άλλο πρόγραμμα.</translation>
    </message>
    <message>
        <source>Do you want to reload the file?</source>
        <translation>Θέλετε να επαναφορτώσετε το αρχείο;</translation>
    </message>
    <message>
        <source>Reload</source>
        <translation>Επαναφόρτωση</translation>
    </message>
    <message>
        <source>Ignore</source>
        <translation>Παράβλεψη</translation>
    </message>
    <message>
        <source>File Deleted</source>
        <translation>Αρχείο Διεγράφη</translation>
    </message>
    <message>
        <source>The file %1 was deleted by another program.</source>
        <translation>Το αρχείο «%1» διεγράφη από άλλο πρόγραμμα.</translation>
    </message>
    <message>
        <source>Do you want to save or close the file?</source>
        <translation>Θέλετε να αποθηκεύσετε ή να κλείσετε το αρχείο;</translation>
    </message>
</context>
<context>
    <name>DocxReader</name>
    <message>
        <source>Unable to open archive.</source>
        <translation>Δεν ήταν δυνατό να ανοίξει η αρχειοθήκη.</translation>
    </message>
</context>
<context>
    <name>FindDialog</name>
    <message>
        <source>Search for:</source>
        <translation>Αναζήτηση για:</translation>
    </message>
    <message>
        <source>Replace with:</source>
        <translation>Αντικατάσταση με:</translation>
    </message>
    <message>
        <source>Ignore case</source>
        <translation>Χωρίς διάκριση πεζών/κεφαλαίων</translation>
    </message>
    <message>
        <source>Whole words only</source>
        <translation>Μόνο ολόκληρες λέξεις</translation>
    </message>
    <message>
        <source>Regular expressions</source>
        <translation>Κανονικές εκφράσεις</translation>
    </message>
    <message>
        <source>Search up</source>
        <translation>Αναζήτηση πάνω</translation>
    </message>
    <message>
        <source>Search down</source>
        <translation>Αναζήτηση κάτω</translation>
    </message>
    <message>
        <source>&amp;Find</source>
        <translation>&amp;Εύρεση</translation>
    </message>
    <message>
        <source>&amp;Replace</source>
        <translation>&amp;Αντικατάσταση</translation>
    </message>
    <message>
        <source>Replace &amp;All</source>
        <translation>Αντικατάσταση &amp;Όλων</translation>
    </message>
    <message>
        <source>Find</source>
        <translation>Εύρεση</translation>
    </message>
    <message>
        <source>Replace</source>
        <translation>Αντικατάσταση</translation>
    </message>
    <message numerus="yes">
        <source>Replace %n instance(s)?</source>
        <translation>
            <numerusform>Αντικατάσταση %n ευρήματος;</numerusform>
            <numerusform>Αντικατάσταση %n ευρημάτων;</numerusform>
        </translation>
    </message>
    <message>
        <source>Question</source>
        <translation>Ερώτηση</translation>
    </message>
    <message>
        <source>Sorry</source>
        <translation>Λυπούμαστε</translation>
    </message>
    <message>
        <source>Phrase not found.</source>
        <translation>Δεν βρέθηκε η φράση.</translation>
    </message>
</context>
<context>
    <name>FormatManager</name>
    <message>
        <source>OpenDocument Text</source>
        <translation>Κείμενο OpenDocument </translation>
    </message>
    <message>
        <source>OpenDocument Flat XML</source>
        <translation>OpenDocument Flat XML</translation>
    </message>
    <message>
        <source>Office Open XML</source>
        <translation>Office Open XML</translation>
    </message>
    <message>
        <source>Rich Text Format</source>
        <translation>Εμπλουτισμένο κείμενο </translation>
    </message>
    <message>
        <source>Plain Text</source>
        <translation>Απλό κείμενο</translation>
    </message>
    <message>
        <source>All Files</source>
        <translation>Όλα τα αρχεία </translation>
    </message>
    <message>
        <source>All Supported Files</source>
        <translation>Όλα τα υποστηριζόμενα αρχεία</translation>
    </message>
</context>
<context>
    <name>Highlighter</name>
    <message>
        <source>Add</source>
        <translation>Προσθήκη</translation>
    </message>
    <message>
        <source>Check Spelling...</source>
        <translation>Ορθογραφικός Έλεγχος...</translation>
    </message>
    <message>
        <source>(No suggestions found)</source>
        <translation>(Δεν βρέθηκαν προτάσεις)</translation>
    </message>
</context>
<context>
    <name>ImageButton</name>
    <message>
        <source>Open Image</source>
        <translation>Άνοιγμα Εικόνας</translation>
    </message>
    <message>
        <source>Images(%1)</source>
        <translation>Εικόνες (%1)</translation>
    </message>
</context>
<context>
    <name>LocaleDialog</name>
    <message>
        <source>Select application language:</source>
        <translation>Επιλέξτε τη γλώσσα της εφαρμογής:</translation>
    </message>
    <message>
        <source>&lt;System Language&gt;</source>
        <translation>&lt;Γλώσσα Συστήματος&gt;</translation>
    </message>
    <message>
        <source>Note</source>
        <translation>Σημείωση</translation>
    </message>
    <message>
        <source>Please restart this application for the change in language to take effect.</source>
        <translation>Επανεκκινήστε την εφαρμογή για να ισχύσει η αλλαγή γλώσσας.</translation>
    </message>
</context>
<context>
    <name>OdtReader</name>
    <message>
        <source>Unable to open archive.</source>
        <translation>Δεν ήταν δυνατό να ανοίξει η αρχειοθήκη.</translation>
    </message>
</context>
<context>
    <name>PreferencesDialog</name>
    <message>
        <source>Preferences</source>
        <translation>Προτιμήσεις</translation>
    </message>
    <message>
        <source>General</source>
        <translation>Γενικά</translation>
    </message>
    <message>
        <source>Statistics</source>
        <translation>Στατιστικά</translation>
    </message>
    <message>
        <source>Toolbar</source>
        <translation>Γραμμή Εργαλείων</translation>
    </message>
    <message>
        <source>Spell Checking</source>
        <translation>Ορθογραφικός Έλεγχος</translation>
    </message>
    <message>
        <source>Select Dictionary</source>
        <translation>Επιλογή Λεξικού</translation>
    </message>
    <message>
        <source>Sorry</source>
        <translation>Λυπούμαστε</translation>
    </message>
    <message>
        <source>Unable to open archive.</source>
        <translation>Δεν ήταν δυνατό να ανοίξει η αρχειοθήκη.</translation>
    </message>
    <message>
        <source>The archive does not contain a usable dictionary.</source>
        <translation>Η αρχειοθήκη δεν περιέχει αξιοποιήσιμο λεξικό.</translation>
    </message>
    <message>
        <source>Question</source>
        <translation>Ερώτηση</translation>
    </message>
    <message>
        <source>Shortcuts</source>
        <translation>Συντομεύσεις</translation>
    </message>
    <message>
        <source>One or more shortcuts conflict. Do you wish to proceed?</source>
        <translation>Μία ή περισσότερες συντομεύσεις συγκρούονται. Θέλετε να συνεχίσετε;</translation>
    </message>
    <message>
        <source>The dictionary &quot;%1&quot; already exists. Do you want to replace it?</source>
        <translation>Το λεξικό «%1» υπάρχει ήδη. Θέλετε να αντικατασταθεί;</translation>
    </message>
    <message>
        <source>Daily Goal</source>
        <translation>Ημερήσιος Στόχος</translation>
    </message>
    <message>
        <source>None</source>
        <translation>Κανένας</translation>
    </message>
    <message>
        <source>Minutes:</source>
        <translation>Λεπτά:</translation>
    </message>
    <message>
        <source>Words:</source>
        <translation>Λέξεις:</translation>
    </message>
    <message>
        <source>Editing</source>
        <translation>Επεξεργασία</translation>
    </message>
    <message>
        <source>Always vertically center</source>
        <translation>Πάντοτε κατακόρυφο κεντράρισμα</translation>
    </message>
    <message>
        <source>Block insertion cursor</source>
        <translation>Παχύς δρομέας εισαγωγής</translation>
    </message>
    <message>
        <source>Smooth fonts</source>
        <translation>Στρογγυλεμένες γραμματοσειρές</translation>
    </message>
    <message>
        <source>Typewriter sounds</source>
        <translation>Ήχοι γραφομηχανής</translation>
    </message>
    <message>
        <source>Smart quotes:</source>
        <translation>Έξυπνα εισαγωγικά:</translation>
    </message>
    <message>
        <source>Double</source>
        <translation>Διπλά</translation>
    </message>
    <message>
        <source>Single</source>
        <translation>Μονά</translation>
    </message>
    <message>
        <source>Scenes</source>
        <translation>Σκηνές</translation>
    </message>
    <message>
        <source>Divider:</source>
        <translation>Διαχωριστικό:</translation>
    </message>
    <message>
        <source>Saving</source>
        <translation>Αποθήκευση</translation>
    </message>
    <message>
        <source>Remember cursor position</source>
        <translation>Μνημόνευση θέσης δρομέα</translation>
    </message>
    <message>
        <source>Word count</source>
        <translation>Αριθμός λέξεων</translation>
    </message>
    <message>
        <source>Page count</source>
        <translation>Αριθμός σελίδων</translation>
    </message>
    <message>
        <source>Paragraph count</source>
        <translation>Αριθμός παραγράφων</translation>
    </message>
    <message>
        <source>Character count</source>
        <translation>Αριθμός χαρακτήρων</translation>
    </message>
    <message>
        <source>Characters:</source>
        <translation>Χαρακτήρες:</translation>
    </message>
    <message>
        <source>Paragraphs:</source>
        <translation>Παράγραφοι:</translation>
    </message>
    <message>
        <source>Word Count Algorithm</source>
        <translation>Αλγόριθμος Καταμέτρησης Λέξεων</translation>
    </message>
    <message>
        <source>Reset daily progress for today to zero?</source>
        <translation>Επαναφορά καθημερινής προόδου για σήμερα στο μηδέν;</translation>
    </message>
    <message>
        <source>Remove current dictionary?</source>
        <translation>Να αφαιρεθεί το υπάρχον λεξικό;</translation>
    </message>
    <message>
        <source>Write byte order mark in plain text files</source>
        <translation>Σήμανση εγγραφής σειράς byte σε αρχεία απλού κειμένου</translation>
    </message>
    <message>
        <source>Default format:</source>
        <translation>Προεπιλεγμένη μορφή:</translation>
    </message>
    <message>
        <source>User Interface</source>
        <translation>Διεπαφή Χρήστη</translation>
    </message>
    <message>
        <source>Always show scrollbar</source>
        <translation>Εμφάνιση πάντα της γραμμής κύλισης</translation>
    </message>
    <message>
        <source>Always show top bar</source>
        <translation>Εμφάνιση πάντα τού top bar</translation>
    </message>
    <message>
        <source>Always show bottom bar</source>
        <translation>Εμφάνιση πάντα τού bottom bar</translation>
    </message>
    <message>
        <source>Reset Today</source>
        <translation>Επαναφορά Σήμερα</translation>
    </message>
    <message>
        <source>History</source>
        <translation>Ιστορικό</translation>
    </message>
    <message>
        <source>Remember history</source>
        <translation>Μνημόνευση ιστορικου</translation>
    </message>
    <message>
        <source>Show streaks</source>
        <translation>Εμφάνιση λωρίδων</translation>
    </message>
    <message>
        <source>Minimum progress for streaks:</source>
        <translation>Ελάχιστη πρόοδος για λωρίδες:</translation>
    </message>
    <message>
        <source>Detect word boundaries</source>
        <translation>Εντοπισμός Ορίων Λέξεων</translation>
    </message>
    <message>
        <source>Divide character count by six</source>
        <translation>Διαίρεση αριθμού χαρακτήρων διά του έξι</translation>
    </message>
    <message>
        <source>Count each letter as a word</source>
        <translation>Καταμέτρηση κάθε γράμμα σαν μια λέξη</translation>
    </message>
    <message>
        <source>Page Count Algorithm</source>
        <translation>Αλγόριθμος αριθμου σελίδων</translation>
    </message>
    <message>
        <source>Style</source>
        <translation>Στυλ</translation>
    </message>
    <message>
        <source>Icons Only</source>
        <translation>Μόνο Εικονίδια</translation>
    </message>
    <message>
        <source>Text Only</source>
        <translation>Μόνο Κείμενο</translation>
    </message>
    <message>
        <source>Text Alongside Icons</source>
        <translation>Κείμενο Πλάι στα Εικονίδια</translation>
    </message>
    <message>
        <source>Text Under Icons</source>
        <translation>Κείμενο Κάτω από τα Εικονίδια</translation>
    </message>
    <message>
        <source>Text Position:</source>
        <translation>Θέση Κειμένου:</translation>
    </message>
    <message>
        <source>Actions</source>
        <translation>Ενέργειες</translation>
    </message>
    <message>
        <source>Move Up</source>
        <translation>Μετακίνηση Πάνω</translation>
    </message>
    <message>
        <source>Move Down</source>
        <translation>Μετακίνηση Κάτω</translation>
    </message>
    <message>
        <source>Add Separator</source>
        <translation>Προσθήκη Διαχωριστικού</translation>
    </message>
    <message>
        <source>Command</source>
        <translation>Εντολή</translation>
    </message>
    <message>
        <source>Shortcut</source>
        <translation>Συντόμευση</translation>
    </message>
    <message>
        <source>Action</source>
        <translation>Ενέργεια</translation>
    </message>
    <message>
        <source>Check spelling as you type</source>
        <translation>Ορθογραφικός έλεγχος κατά την πληκτρολόγηση</translation>
    </message>
    <message>
        <source>Ignore words in UPPERCASE</source>
        <translation>Παράβλεψη λέξεων σε ΚΕΦΑΛΑΙΑ</translation>
    </message>
    <message>
        <source>Ignore words with numbers</source>
        <translation>Παράβλεψη λέξεων με αριθμούς</translation>
    </message>
    <message>
        <source>Language</source>
        <translation>Γλώσσα</translation>
    </message>
    <message>
        <source>Add</source>
        <translation>Προσθήκη</translation>
    </message>
    <message>
        <source>Remove</source>
        <translation>Αφαίρεση</translation>
    </message>
    <message>
        <source>Personal Dictionary</source>
        <translation>Προσωπικό Λεξικό</translation>
    </message>
</context>
<context>
    <name>RtfReader</name>
    <message>
        <source>Not a supported RTF file.</source>
        <translation>Μη υποστηριζόμενο αρχείο RTF.</translation>
    </message>
</context>
<context>
    <name>RtfTokenizer</name>
    <message>
        <source>Unexpectedly reached end of file.</source>
        <translation>Απρόσμενη μετάβαση στο τέλος του αρχείου.</translation>
    </message>
</context>
<context>
    <name>SceneList</name>
    <message>
        <source>Ctrl+Shift+Down</source>
        <translation>Ctrl+Shift+Κάτω</translation>
    </message>
    <message>
        <source>Move Scenes Up</source>
        <translation>Μετακίνηση Σκηνών Πάνω</translation>
    </message>
    <message>
        <source>Ctrl+Shift+Up</source>
        <translation>Ctrl+Shift+Πάνω</translation>
    </message>
    <message>
        <source>Toggle Scene List</source>
        <translation>Εναλλαγή Λίστας Σκηνών</translation>
    </message>
    <message>
        <source>Shift+F4</source>
        <translation>Shift+F4</translation>
    </message>
    <message>
        <source>Show scene list (%1)</source>
        <translation>Εμφάνιση λίστας σκηνών (%1)</translation>
    </message>
    <message>
        <source>Hide scene list (%1)</source>
        <translation>Απόκρυψη λίστας σκηνών (%1)</translation>
    </message>
    <message>
        <source>Filter</source>
        <translation>Φιλτράρισμα</translation>
    </message>
    <message>
        <source>Move Scenes Down</source>
        <translation>Μετακίνηση Σκηνών Κάτω</translation>
    </message>
    <message>
        <source>Resize scene list</source>
        <translation>Αλλαγή μεγέθους λίστας σκηνών</translation>
    </message>
</context>
<context>
    <name>Session</name>
    <message>
        <source>Default</source>
        <translation>Προεπιλογή</translation>
    </message>
</context>
<context>
    <name>SessionManager</name>
    <message>
        <source>Manage Sessions</source>
        <translation>Διαχείριση Περιόδων Λειτουργίας</translation>
    </message>
    <message>
        <source>S&amp;essions</source>
        <translation>Π&amp;ερίοδοι λειτουργίας</translation>
    </message>
    <message>
        <source>New</source>
        <translation>Νέα</translation>
    </message>
    <message>
        <source>Duplicate</source>
        <translation>Διπλότυπο</translation>
    </message>
    <message>
        <source>Rename</source>
        <translation>Μετονομασία</translation>
    </message>
    <message>
        <source>Delete</source>
        <translation>Διαγραφή</translation>
    </message>
    <message>
        <source>Switch To</source>
        <translation>Εναλλαγή Σε</translation>
    </message>
    <message>
        <source>New Session</source>
        <translation>Νέα Περίοδος Λειτουργίας</translation>
    </message>
    <message>
        <source>Duplicate Session</source>
        <translation>Περιόδος λειτουργίας διπλότυπου</translation>
    </message>
    <message>
        <source>Rename Session</source>
        <translation>Μετονομασία Περιόδου Λειτουργίας</translation>
    </message>
    <message>
        <source>Question</source>
        <translation>Ερώτηση</translation>
    </message>
    <message>
        <source>Delete selected session?</source>
        <translation>Να διαγραφή η επιλεγμένη περιόδου λειτουργίας;</translation>
    </message>
    <message>
        <source>Session name:</source>
        <translation>Όνομα περιόδου λειτουργίας:</translation>
    </message>
    <message>
        <source>Sorry</source>
        <translation>Λυπούμαστε</translation>
    </message>
    <message>
        <source>The requested session name is already in use.</source>
        <translation>Αυτό το όνομα χρησιμοποιείται ήδη για άλλη περίοδο λειτουργίας.</translation>
    </message>
    <message>
        <source>&amp;New...</source>
        <translation>&amp;Νέα...</translation>
    </message>
    <message>
        <source>Ctrl+Shift+N</source>
        <translation>Ctrl+Shift+N</translation>
    </message>
    <message>
        <source>&amp;Manage...</source>
        <translation>&amp;Διαχείριση...</translation>
    </message>
    <message>
        <source>Ctrl+Shift+M</source>
        <translation>Ctrl+Shift+M</translation>
    </message>
</context>
<context>
    <name>ShortcutEdit</name>
    <message>
        <source>Clear</source>
        <translation>Εκκαθάριση</translation>
    </message>
    <message>
        <source>Reset to Default</source>
        <translation>Επαναφορά στα Προκαθορισμένα</translation>
    </message>
    <message>
        <source>Shortcut:</source>
        <translation>Συντόμευση:</translation>
    </message>
</context>
<context>
    <name>SmartQuote</name>
    <message>
        <source>Replacing quotation marks...</source>
        <translation>Αντικατάσταση εισαγωγικών...</translation>
    </message>
    <message>
        <source>Please Wait</source>
        <translation>Παρακαλώ Περιμένετε</translation>
    </message>
</context>
<context>
    <name>SpellChecker</name>
    <message>
        <source>Check Spelling</source>
        <translation>Ορθογραφικός Έλεγχος</translation>
    </message>
    <message>
        <source>&amp;Add</source>
        <translation>&amp;Προσθήκη</translation>
    </message>
    <message>
        <source>&amp;Ignore</source>
        <translation>Πα&amp;ράβλεψη</translation>
    </message>
    <message>
        <source>I&amp;gnore All</source>
        <translation>Παράβλε&amp;ψη Όλων</translation>
    </message>
    <message>
        <source>&amp;Change</source>
        <translation>&amp;Αλλαγή</translation>
    </message>
    <message>
        <source>C&amp;hange All</source>
        <translation>Α&amp;λλαγή Όλων</translation>
    </message>
    <message>
        <source>Not in dictionary:</source>
        <translation>Δεν υπάρχει στο λεξικό:</translation>
    </message>
    <message>
        <source>Change to:</source>
        <translation>Αλλαγή σε:</translation>
    </message>
    <message>
        <source>Checking spelling...</source>
        <translation>Γίνεται έλεγχος ορθογραφίας...</translation>
    </message>
    <message>
        <source>Cancel</source>
        <translation>Ακύρωση</translation>
    </message>
    <message>
        <source>Please wait</source>
        <translation>Παρακαλώ Περιμένετε</translation>
    </message>
    <message>
        <source>Continue checking at beginning of file?</source>
        <translation>Να συνεχιστεί ο έλεγχος από την αρχή του αρχείου;</translation>
    </message>
    <message>
        <source>Spell check complete.</source>
        <translation>Ο ορθογραφικός έλεγχος ολοκληρώθηκε.</translation>
    </message>
</context>
<context>
    <name>SymbolsDialog</name>
    <message>
        <source>Symbols</source>
        <translation>Σύμβολα</translation>
    </message>
    <message>
        <source>Recently used symbols</source>
        <translation>Πρόσφατα σύμβολα</translation>
    </message>
    <message>
        <source>All symbols</source>
        <translation>Όλα τα σύμβολα</translation>
    </message>
    <message>
        <source>Details</source>
        <translation>Λεπτομέρειες</translation>
    </message>
    <message>
        <source>Name:</source>
        <translation>Όνομα:</translation>
    </message>
    <message>
        <source>Insert</source>
        <translation>Εισαγωγή</translation>
    </message>
</context>
<context>
    <name>SymbolsModel</name>
    <message>
        <source>Blocks</source>
        <translation>Κουτάκια</translation>
    </message>
    <message>
        <source>Scripts</source>
        <translation>Γραφές</translation>
    </message>
</context>
<context>
    <name>Theme</name>
    <message>
        <source>Untitled %1</source>
        <translation>Χωρίς τίτλο %1</translation>
    </message>
</context>
<context>
    <name>ThemeDialog</name>
    <message>
        <source>Name:</source>
        <translation>Όνομα:</translation>
    </message>
    <message>
        <source>No Image</source>
        <translation>Χωρίς Εικόνα</translation>
    </message>
    <message>
        <source>Tiled</source>
        <translation>Επαναλαμβανόμενη</translation>
    </message>
    <message>
        <source>Centered</source>
        <translation>Κεντραρισμένη</translation>
    </message>
    <message>
        <source>Stretched</source>
        <translation>Τεντωμένη</translation>
    </message>
    <message>
        <source>Scaled</source>
        <translation>Κλιμακωμένη</translation>
    </message>
    <message>
        <source>Zoomed</source>
        <translation>Μεγεθυσμένη</translation>
    </message>
    <message>
        <source>Opacity:</source>
        <translation>Αδιαφάνεια:</translation>
    </message>
    <message>
        <source>Position:</source>
        <translation>Θέση:</translation>
    </message>
    <message>
        <source>Width:</source>
        <translation>Πλάτος:</translation>
    </message>
    <message>
        <source>Round Text Background Corners</source>
        <translation>Γύρος φόντου κειμένου γωνιών</translation>
    </message>
    <message>
        <source>Radius:</source>
        <translation>Ακτίνα:</translation>
    </message>
    <message>
        <source>Blur Text Background</source>
        <translation>Θόλωμα φόντου κειμένου</translation>
    </message>
    <message>
        <source>Text Background Drop Shadow</source>
        <translation>Φόντος κειμένου προσπίπτουσα σκιά</translation>
    </message>
    <message>
        <source>Vertical Offset:</source>
        <translation>Κάθετη Μετατόπιση:</translation>
    </message>
    <message>
        <source>Margins</source>
        <translation>Περιθώρια:</translation>
    </message>
    <message>
        <source>Window:</source>
        <translation>Παράθυρο:</translation>
    </message>
    <message>
        <source>Page:</source>
        <translation>Σελίδα:</translation>
    </message>
    <message>
        <source>Indent first line</source>
        <translation>Εσοχή πρώτης γραμμής</translation>
    </message>
    <message>
        <source>Above:</source>
        <translation>Παραπάνω:</translation>
    </message>
    <message>
        <source>Below:</source>
        <translation>Παρακάτω:</translation>
    </message>
    <message>
        <source>Remove</source>
        <translation>Αφαίρεση</translation>
    </message>
    <message>
        <source>Edit Theme</source>
        <translation>Επεξεργασία θέματος</translation>
    </message>
    <message>
        <source>Window Background</source>
        <translation>Φόντος παραθύρου </translation>
    </message>
    <message>
        <source>Type:</source>
        <translation>Τύπος:</translation>
    </message>
    <message>
        <source>Color:</source>
        <translation>Χρώμα:</translation>
    </message>
    <message>
        <source>Image:</source>
        <translation>Εικόνα:</translation>
    </message>
    <message>
        <source> pixels</source>
        <translation>pixel</translation>
    </message>
    <message>
        <source>Left</source>
        <translation>Αριστερά</translation>
    </message>
    <message>
        <source>Text Background</source>
        <translation>Φόντος κειμένου</translation>
    </message>
    <message>
        <source>Right</source>
        <translation>Δεξιά</translation>
    </message>
    <message>
        <source>Text</source>
        <translation>Κείμενο</translation>
    </message>
    <message>
        <source>Font:</source>
        <translation>Γραμματοσειρά:</translation>
    </message>
    <message>
        <source>Misspelled:</source>
        <translation>Ανορθογραφίες:</translation>
    </message>
    <message>
        <source>Line Spacing</source>
        <translation>Απόσταση Γραμμών</translation>
    </message>
    <message>
        <source>Single</source>
        <translation>Μονή</translation>
    </message>
    <message>
        <source>1.5 Lines</source>
        <translation>1,5 Γραμμή</translation>
    </message>
    <message>
        <source>Double</source>
        <translation>Διπλή</translation>
    </message>
    <message>
        <source>Proportional</source>
        <translation>Αναλογική</translation>
    </message>
    <message>
        <source>Height:</source>
        <translation>Ύψος:</translation>
    </message>
    <message>
        <source>Paragraph Spacing</source>
        <translation>Απόσταση Παραγράφων</translation>
    </message>
    <message>
        <source>Tab Width:</source>
        <translation>Πλάτος καρτέλας:</translation>
    </message>
    <message>
        <source>New Theme</source>
        <translation>Νέο θέμα</translation>
    </message>
</context>
<context>
    <name>ThemeManager</name>
    <message>
        <source>Themes</source>
        <translation>Θέματα</translation>
    </message>
    <message>
        <source>Default</source>
        <translation>Προεπιλογή</translation>
    </message>
    <message>
        <source>Bitter Skies</source>
        <translation>Πικρά Ουράνια</translation>
    </message>
    <message>
        <source>Enchantment</source>
        <translation>Μαγεία</translation>
    </message>
    <message>
        <source>Gentle Blues</source>
        <translation>Gentle Blues</translation>
    </message>
    <message>
        <source>Old School</source>
        <translation>Old School</translation>
    </message>
    <message>
        <source>Space Dreams</source>
        <translation>Space Dreams</translation>
    </message>
    <message>
        <source>Spy Games</source>
        <translation>Παιχνίδια Κατασκοπίας</translation>
    </message>
    <message>
        <source>Tranquility</source>
        <translation>Ηρεμία</translation>
    </message>
    <message>
        <source>Writing Desk</source>
        <translation>Writing Desk</translation>
    </message>
    <message>
        <source>New</source>
        <translation>Νέο</translation>
    </message>
    <message>
        <source>Duplicate</source>
        <translation>Διπλότυπο</translation>
    </message>
    <message>
        <source>Custom</source>
        <translation>Προσαρμοσμένο</translation>
    </message>
    <message>
        <source>Edit</source>
        <translation>Επεξεργασία</translation>
    </message>
    <message>
        <source>Delete</source>
        <translation>Διαγραφή</translation>
    </message>
    <message>
        <source>Import</source>
        <translation>Εισαγωγή</translation>
    </message>
    <message>
        <source>Export</source>
        <translation>Εξαγωγή</translation>
    </message>
    <message>
        <source>Question</source>
        <translation>Ερώτηση</translation>
    </message>
    <message>
        <source>Delete theme &apos;%1&apos;?</source>
        <translation>Διαγραφή θέματος &apos;%1&apos;;</translation>
    </message>
    <message>
        <source>Themes (%1)</source>
        <translation>Θέματα (%1)</translation>
    </message>
    <message>
        <source>Import Theme</source>
        <translation>Εισαγωγή Θέματος</translation>
    </message>
    <message>
        <source>Export Theme</source>
        <translation>Εξαγωγή Θέματος</translation>
    </message>
</context>
<context>
    <name>Timer</name>
    <message>
        <source>&lt;b&gt;%1&lt;/b&gt; - %2</source>
        <translation>&lt;b&gt;%1&lt;/b&gt; - %2</translation>
    </message>
    <message>
        <source>Question</source>
        <translation>Ερώτηση</translation>
    </message>
    <message>
        <source>Delete timer?</source>
        <translation>Να διαγραφεί το χρονομέτρο;</translation>
    </message>
    <message>
        <source>&lt;b&gt;Words:&lt;/b&gt; %L1</source>
        <translation>&lt;b&gt;Λέξεις:&lt;/b&gt; %L1</translation>
    </message>
    <message>
        <source>&lt;b&gt;Pages:&lt;/b&gt; %L1</source>
        <translation>&lt;b&gt;Σελίδες:&lt;/b&gt; %L1</translation>
    </message>
    <message>
        <source>&lt;b&gt;Paragraphs:&lt;/b&gt; %L1</source>
        <translation>&lt;b&gt;Παράγραφοι:&lt;/b&gt; %L1</translation>
    </message>
    <message>
        <source>&lt;b&gt;Characters:&lt;/b&gt; %L1 / %L2</source>
        <translation>&lt;b&gt;Χαρακτήρες:&lt;/b&gt; %L1 / %L2</translation>
    </message>
    <message>
        <source>Set Delay</source>
        <translation>Ορισμός Καθυστέρησης</translation>
    </message>
    <message>
        <source>Set Time</source>
        <translation>Ορισμός Ώρας</translation>
    </message>
    <message>
        <source>Delay:</source>
        <translation>Καθυστέρηση:</translation>
    </message>
    <message>
        <source>Time:</source>
        <translation>Ώρα:</translation>
    </message>
    <message>
        <source>HH:mm:ss</source>
        <translation>ΩΩ:λλ:δδ</translation>
    </message>
    <message>
        <source>Alarm</source>
        <translation>Ειδοποίηση</translation>
    </message>
    <message>
        <source>Type:</source>
        <translation>Τύπος:</translation>
    </message>
    <message>
        <source>Memo:</source>
        <translation>Υπόμνημα:</translation>
    </message>
    <message>
        <source>Edit</source>
        <translation>Επεξεργασία</translation>
    </message>
    <message>
        <source>Delete</source>
        <translation>Διαγραφή</translation>
    </message>
</context>
<context>
    <name>TimerDisplay</name>
    <message>
        <source>HH:mm:ss</source>
        <translation>ΩΩ:λλ:δδ</translation>
    </message>
    <message>
        <source>No timers running</source>
        <translation>Δεν λειτουργούν χρονόμετρα</translation>
    </message>
</context>
<context>
    <name>TimerManager</name>
    <message>
        <source>Timers</source>
        <translation>Χρονόμετρα</translation>
    </message>
    <message>
        <source>New</source>
        <translation>Νέο</translation>
    </message>
    <message>
        <source>Recent</source>
        <translation>Πρόσφατα</translation>
    </message>
    <message>
        <source>Question</source>
        <translation>Ερώτηση</translation>
    </message>
    <message>
        <source>Cancel editing timers?</source>
        <translation>Να ακυρωθεί η επεξεργασία χρονομέτρων;</translation>
    </message>
    <message>
        <source>+HH:mm:ss</source>
        <translation>+ΩΩ:λλ:δδ</translation>
    </message>
    <message>
        <source>%1 - %2</source>
        <translation>%1 - %2</translation>
    </message>
</context>
<context>
    <name>Window</name>
    <message>
        <source>Loading themes</source>
        <translation>Φορτώνουν θέματα</translation>
    </message>
    <message>
        <source>Loading sounds</source>
        <translation>Φορτώνουν ήχοι</translation>
    </message>
    <message>
        <source>Untitled</source>
        <translation>Χωρίς τίτλο </translation>
    </message>
    <message>
        <source>Open File</source>
        <translation>Άνοιγμα Αρχείου</translation>
    </message>
    <message>
        <source>About FocusWriter</source>
        <translation>Σχετικά με το FocusWriter</translation>
    </message>
    <message>
        <source>FocusWriter</source>
        <translation>FocusWriter</translation>
    </message>
    <message>
        <source>A simple fullscreen word processor</source>
        <translation>Ένας απλός επεξεργαστής κειμένου πλήρης οθόνης</translation>
    </message>
    <message>
        <source>Copyright &amp;copy; 2008-%1 Graeme Gott</source>
        <translation>Πνευματική ιδιοκτησία του &amp;copy; 2008-%1 Graeme Gott</translation>
    </message>
    <message>
        <source>Released under the &lt;a href=%1&gt;GPL 3&lt;/a&gt; license</source>
        <translation>Κυκλοφορεί υπό την άδεια χρήσης &lt;a href=%1&gt;GPL 3&lt;/a&gt; </translation>
    </message>
    <message>
        <source>Uses icons from the &lt;a href=%1&gt;Oxygen&lt;/a&gt; icon theme</source>
        <translation>Χρησιμοποιεί εικονίδια από το θέμα εικονιδίων &lt;a href=%1&gt;Oxygen&lt;/a&gt; </translation>
    </message>
    <message>
        <source>Used under the &lt;a href=%1&gt;LGPL 3&lt;/a&gt; license</source>
        <translation>Χρησιμοποιούνται υπό την άδεια χρήσης &lt;a href=%1&gt;LGPL 3&lt;/ a&gt;</translation>
    </message>
    <message>
        <source>Characters: %L1 / %L2</source>
        <translation>Χαρακτήρες: %L1 / %L2</translation>
    </message>
    <message>
        <source>Pages: %L1</source>
        <translation>Σελίδες: %L1</translation>
    </message>
    <message>
        <source>Paragraphs: %L1</source>
        <translation>Παράγραφοι: %L1</translation>
    </message>
    <message>
        <source>Words: %L1</source>
        <translation>Λέξεις: %L1</translation>
    </message>
    <message>
        <source>Opening %1</source>
        <translation>Ανοίγει το %1</translation>
    </message>
    <message>
        <source>(Untitled %1)</source>
        <translation>(Χωρίς τίτλο %1)</translation>
    </message>
    <message>
        <source>List all documents</source>
        <translation>Λίστα όλων των εγγράφων</translation>
    </message>
    <message>
        <source>Switch to Next Document</source>
        <translation>Μετάβαση στο Επόμενο Έγγραφο</translation>
    </message>
    <message>
        <source>Switch to Previous Document</source>
        <translation>Μετάβαση στο Προηγούμενο Έγγραφο</translation>
    </message>
    <message>
        <source>Switch to First Document</source>
        <translation>Μετάβαση στο Πρώτο Έγγραφο</translation>
    </message>
    <message>
        <source>Switch to Last Document</source>
        <translation>Μετάβαση στο Τελευταίο Έγγραφο</translation>
    </message>
    <message>
        <source>Switch to Document %1</source>
        <translation>Μετάβαση στο Έγγραφο %1</translation>
    </message>
    <message>
        <source>Loading settings</source>
        <translation>Φορτώνουν ρυθμίσεις</translation>
    </message>
    <message>
        <source>Emergency cache is not writable.</source>
        <translation>Δεν μπορεί να γίνει εγγραφή στην κρυφή μνήμη εκτάκτου ανάγκης.</translation>
    </message>
    <message>
        <source>Warning</source>
        <translation>Προειδοποίηση</translation>
    </message>
    <message>
        <source>FocusWriter was not shut down cleanly.</source>
        <translation>Το FocusWriter δεν τερματίστηκε σωστά.</translation>
    </message>
    <message>
        <source>Restore from the emergency cache?</source>
        <translation>Να γίνει επαναφορά από τη μνήμη εκτάκτου ανάγκης;</translation>
    </message>
    <message>
        <source>Some files could not be opened.</source>
        <translation>Ορισμένα αρχεία δεν ήταν δυνατό να ανοιχτούν.</translation>
    </message>
    <message>
        <source>Some files were opened Read-Only.</source>
        <translation>Ορισμένα αρχεία ανοίχτηκαν ως μόνο για ανάγνωση.</translation>
    </message>
    <message>
        <source>&apos;%1&apos; is newer than the cached copy.</source>
        <translation>Το «%1» είναι νεότερο από το αντίγραφο στη μνήμη.</translation>
    </message>
    <message>
        <source>Overwrite newer file?</source>
        <translation>Να αντικατασταθεί το νεότερο αρχείο;</translation>
    </message>
    <message>
        <source>Save Changes?</source>
        <translation>Να αποθηκευτούν οι αλλαγές;</translation>
    </message>
    <message>
        <source>Save changes to the file &apos;%1&apos; before closing?</source>
        <translation>Αποθήκευση αλλαγών στο αρχείο &apos;%1&apos; πριν το κλείσιμο;</translation>
    </message>
    <message>
        <source>Your changes will be lost if you don&apos;t save them.</source>
        <translation>Οι αλλαγές σας θα χαθούν αν δεν τις αποθηκεύσετε.</translation>
    </message>
    <message>
        <source>Unable to load typewriter sounds.</source>
        <translation>Δεν ήταν δυνατό να φορτώσουν οι ήχοι γραφομηχανής.</translation>
    </message>
    <message>
        <source>&amp;File</source>
        <translation>&amp;Αρχείο</translation>
    </message>
    <message>
        <source>&amp;New</source>
        <translation>&amp;Νέο</translation>
    </message>
    <message>
        <source>&amp;Open...</source>
        <translation>Άν&amp;οιγμα...</translation>
    </message>
    <message>
        <source>Reloa&amp;d</source>
        <translation>Επαναφόρτωσ&amp;η</translation>
    </message>
    <message>
        <source>&amp;Save</source>
        <translation>Αποθήκευ&amp;ση</translation>
    </message>
    <message>
        <source>Save &amp;As...</source>
        <translation>Αποθήκευση &amp;ως...</translation>
    </message>
    <message>
        <source>&amp;Rename...</source>
        <translation>&amp;Μετονομασία...</translation>
    </message>
    <message>
        <source>Save A&amp;ll</source>
        <translation>Αποθήκευση ό&amp;λων</translation>
    </message>
    <message>
        <source>Manage Sessions</source>
        <translation>Διαχείριση Περιόδων Λειτουργίας</translation>
    </message>
    <message>
        <source>New Session</source>
        <translation>Νέα Περίοδος Λειτουργίας</translation>
    </message>
    <message>
        <source>&amp;Print...</source>
        <translation>Εκτύ&amp;πωση...</translation>
    </message>
    <message>
        <source>Pa&amp;ge Setup...</source>
        <translation>Δι&amp;αμόρφωση Σελίδας...</translation>
    </message>
    <message>
        <source>&amp;Close</source>
        <translation>&amp;Κλείσιμο</translation>
    </message>
    <message>
        <source>&amp;Quit</source>
        <translation>Έξο&amp;δος</translation>
    </message>
    <message>
        <source>Ctrl+Q</source>
        <translation>Ctrl+Q</translation>
    </message>
    <message>
        <source>&amp;Edit</source>
        <translation>&amp;Επεξεργασία</translation>
    </message>
    <message>
        <source>&amp;Undo</source>
        <translation>&amp;Αναίρεση</translation>
    </message>
    <message>
        <source>&amp;Redo</source>
        <translation>Ε&amp;πανάληψη</translation>
    </message>
    <message>
        <source>Cu&amp;t</source>
        <translation>Απο&amp;κοπή</translation>
    </message>
    <message>
        <source>&amp;Copy</source>
        <translation>Αν&amp;τιγραφή</translation>
    </message>
    <message>
        <source>&amp;Paste</source>
        <translation>Επικό&amp;λληση</translation>
    </message>
    <message>
        <source>Paste &amp;Unformatted</source>
        <translation>Επικόλληση &amp;Χωρίς Μορφοποίηση</translation>
    </message>
    <message>
        <source>Ctrl+Shift+V</source>
        <translation>Ctrl+Shift+V</translation>
    </message>
    <message>
        <source>Select &amp;All</source>
        <translation>Επιλογή Όλ&amp;ων</translation>
    </message>
    <message>
        <source>Select &amp;Scene</source>
        <translation>Επιλογή &amp;Σκηνής</translation>
    </message>
    <message>
        <source>Ctrl+Shift+A</source>
        <translation>Ctrl+Shift+A</translation>
    </message>
    <message>
        <source>Fo&amp;rmat</source>
        <translation>&amp;Μορφοποίηση</translation>
    </message>
    <message>
        <source>&amp;Heading</source>
        <translation>Επικεφαλίδα</translation>
    </message>
    <message>
        <source>Heading &amp;1</source>
        <translation>Επικεφαλίδα &amp;1</translation>
    </message>
    <message>
        <source>Heading &amp;2</source>
        <translation>Επικεφαλίδα &amp;2</translation>
    </message>
    <message>
        <source>Heading &amp;3</source>
        <translation>Επικεφαλίδα &amp;3</translation>
    </message>
    <message>
        <source>Heading &amp;4</source>
        <translation>Επικεφαλίδα &amp;4</translation>
    </message>
    <message>
        <source>Heading &amp;5</source>
        <translation>Επικεφαλίδα &amp;5</translation>
    </message>
    <message>
        <source>Heading &amp;6</source>
        <translation>Επικεφαλίδα &amp;6</translation>
    </message>
    <message>
        <source>&amp;Normal</source>
        <translation>Απλή</translation>
    </message>
    <message>
        <source>&amp;Bold</source>
        <translation>Έντ&amp;ονα</translation>
    </message>
    <message>
        <source>&amp;Italic</source>
        <translation>&amp;Πλάγια</translation>
    </message>
    <message>
        <source>&amp;Underline</source>
        <translation>&amp;Υπογραμμισμένα</translation>
    </message>
    <message>
        <source>Stri&amp;kethrough</source>
        <translation>Διαγραμμέ&amp;να</translation>
    </message>
    <message>
        <source>Ctrl+K</source>
        <translation>Ctrl+K</translation>
    </message>
    <message>
        <source>Sup&amp;erscript</source>
        <translation>&amp;Εκθέτης</translation>
    </message>
    <message>
        <source>Ctrl+^</source>
        <translation>Ctrl+^</translation>
    </message>
    <message>
        <source>&amp;Subscript</source>
        <translation>&amp;Δείκτης</translation>
    </message>
    <message>
        <source>Ctrl+_</source>
        <translation>Ctrl+_</translation>
    </message>
    <message>
        <source>Align &amp;Left</source>
        <translation>Στοίχιση &amp;Αριστερά</translation>
    </message>
    <message>
        <source>Ctrl+{</source>
        <translation>Ctrl+{</translation>
    </message>
    <message>
        <source>Align &amp;Center</source>
        <translation>Στοίχιση στο Κέν&amp;τρο</translation>
    </message>
    <message>
        <source>Ctrl+|</source>
        <translation>Ctrl+|</translation>
    </message>
    <message>
        <source>Align &amp;Right</source>
        <translation>Στοίχιση &amp;Δεξιά</translation>
    </message>
    <message>
        <source>Ctrl+}</source>
        <translation>Ctrl+}</translation>
    </message>
    <message>
        <source>Align &amp;Justify</source>
        <translation>Πλήρης &amp;Στοίχιση</translation>
    </message>
    <message>
        <source>Ctrl+J</source>
        <translation>Ctrl+J</translation>
    </message>
    <message>
        <source>&amp;Decrease Indent</source>
        <translation>Μεί&amp;ωση Εσοχής</translation>
    </message>
    <message>
        <source>Ctrl+&lt;</source>
        <translation>Ctrl+&lt;</translation>
    </message>
    <message>
        <source>I&amp;ncrease Indent</source>
        <translation>Αύ&amp;ξηση Εσοχής</translation>
    </message>
    <message>
        <source>Ctrl+&gt;</source>
        <translation>Ctrl+&gt;</translation>
    </message>
    <message>
        <source>Le&amp;ft to Right Block</source>
        <translation>Δεξιόστ&amp;ροφη Γραφή</translation>
    </message>
    <message>
        <source>Ri&amp;ght to Left Block</source>
        <translation>Αριστερόστρο&amp;φη Γραφή</translation>
    </message>
    <message>
        <source>&amp;Tools</source>
        <translation>Εργα&amp;λεία</translation>
    </message>
    <message>
        <source>&amp;Find...</source>
        <translation>Εύρε&amp;ση...</translation>
    </message>
    <message>
        <source>Find &amp;Next</source>
        <translation>Εύρεση &amp;Επόμενου</translation>
    </message>
    <message>
        <source>Find Pre&amp;vious</source>
        <translation>Εύρεση &amp;Προηγούμενου</translation>
    </message>
    <message>
        <source>&amp;Replace...</source>
        <translation>&amp;Αντικατάσταση...</translation>
    </message>
    <message>
        <source>Ctrl+R</source>
        <translation>Ctrl+R</translation>
    </message>
    <message>
        <source>Smart &amp;Quotes</source>
        <translation>Έξυπνα Εισαγ&amp;ωγικά</translation>
    </message>
    <message>
        <source>Update &amp;Document</source>
        <translation>Ενη&amp;μέρωση εγγράφου</translation>
    </message>
    <message>
        <source>Update Document Smart Quotes</source>
        <translation>Ενημέρωση εισαγωγικών εγγράφου</translation>
    </message>
    <message>
        <source>Update &amp;Selection</source>
        <translation>Ε&amp;νημέρωση Επιλογής</translation>
    </message>
    <message>
        <source>Update Selection Smart Quotes</source>
        <translation>Ενημέρωση επιλογής εισαγωγικών εγγράφου</translation>
    </message>
    <message>
        <source>&amp;Spelling...</source>
        <translation>Ορ&amp;θογραφία...</translation>
    </message>
    <message>
        <source>F7</source>
        <translation>F7</translation>
    </message>
    <message>
        <source>Set &amp;Language...</source>
        <translation>Ρύθμιση γλώσσας...</translation>
    </message>
    <message>
        <source>&amp;Timers...</source>
        <translation>Χρονόμε&amp;τρα...</translation>
    </message>
    <message>
        <source>S&amp;ymbols...</source>
        <translation>Σύμ&amp;βολα...</translation>
    </message>
    <message>
        <source>&amp;Daily Progress</source>
        <translation>Καθημερινή πρόοδος</translation>
    </message>
    <message>
        <source>&amp;Settings</source>
        <translation>&amp;Ρυθμίσεις</translation>
    </message>
    <message>
        <source>Show &amp;Toolbar</source>
        <translation>Εμφάνιση Γραμμής Εργα&amp;λείων</translation>
    </message>
    <message>
        <source>Show &amp;Menu Icons</source>
        <translation>Εμφάνιση Εικονιδίων &amp;Μενού</translation>
    </message>
    <message>
        <source>F&amp;ocused Text</source>
        <translation>Εστιασμένο &amp;Κείμενο</translation>
    </message>
    <message>
        <source>&amp;Fullscreen</source>
        <translation>Πλήρης Οθό&amp;νη</translation>
    </message>
    <message>
        <source>F11</source>
        <translation>F11</translation>
    </message>
    <message>
        <source>Esc</source>
        <translation>Esc</translation>
    </message>
    <message>
        <source>M&amp;inimize</source>
        <translation>Ελαχι&amp;στοποίηση</translation>
    </message>
    <message>
        <source>Ctrl+M</source>
        <translation>Ctrl+M</translation>
    </message>
    <message>
        <source>&amp;Themes...</source>
        <translation>&amp;Θέματα...</translation>
    </message>
    <message>
        <source>&amp;Preferences...</source>
        <translation>Προ&amp;τιμήσεις...</translation>
    </message>
    <message>
        <source>Focus Off</source>
        <translation>Εστίαση Ανενεργή</translation>
    </message>
    <message>
        <source>Focus One Line</source>
        <translation>Εστίαση Μίας Γραμμής</translation>
    </message>
    <message>
        <source>Focus Three Lines</source>
        <translation>Εστίαση Τριών Γραμμών</translation>
    </message>
    <message>
        <source>&amp;Paragraph</source>
        <translation>&amp;Παραγράφου</translation>
    </message>
    <message>
        <source>Focus Paragraph</source>
        <translation>Εστίαση Παραγράφου</translation>
    </message>
    <message>
        <source>Ctrl+Shift+`</source>
        <translation>Ctrl+Shift+`</translation>
    </message>
    <message>
        <source>&amp;Help</source>
        <translation>&amp;Βοήθεια</translation>
    </message>
    <message>
        <source>Application &amp;Language...</source>
        <translation>&amp;Γλώσσα Εφαρμογής...</translation>
    </message>
    <message>
        <source>Some files were unsupported and could not be opened.</source>
        <translation>Ορισμένα αρχεία δεν υποστηρίζονται και δεν ήταν δυνατό να ανοιχτούν.</translation>
    </message>
    <message>
        <source>&amp;Off</source>
        <translation>&amp;Απενεργοποίηση</translation>
    </message>
    <message>
        <source>One &amp;Line</source>
        <translation>&amp;Μία Γραμμή</translation>
    </message>
    <message>
        <source>&amp;Three Lines</source>
        <translation>&amp;Τρεις Γραμμές</translation>
    </message>
    <message>
        <source>&amp;About</source>
        <translation>&amp;Σχετικά</translation>
    </message>
    <message>
        <source>About &amp;Qt</source>
        <translation>&amp;Σχετικά με το Qt</translation>
    </message>
</context>
</TS>
